You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [5/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthenticatingRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthenticatingRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/CachingRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/CachingRealm.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.cache.CacheManagerAware;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.cache.CacheManagerAware;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/Realm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/Realm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,22 +1,22 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Realms that acquire security data from a Microsoft Active Directory.
- */
-package org.apache.ki.realm.activedirectory;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Realms that acquire security data from a Microsoft Active Directory.
+ */
+package org.apache.shiro.realm.activedirectory;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/JdbcRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/JdbcRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Realms that acquire security data from an RDBMS (Relational Database Management System) using the 
- * JDBC API.
- */
-package org.apache.ki.realm.jdbc;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Realms that acquire security data from an RDBMS (Relational Database Management System) using the 
+ * JDBC API.
+ */
+package org.apache.shiro.realm.jdbc;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/JndiRealmFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/JndiRealmFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/JndiRealmFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/JndiRealmFactory.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.jndi;
+package org.apache.shiro.realm.jndi;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.ki.jndi.JndiLocator;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.realm.RealmFactory;
-import org.apache.ki.util.StringUtils;
+import org.apache.shiro.jndi.JndiLocator;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.realm.RealmFactory;
+import org.apache.shiro.util.StringUtils;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/DefaultLdapContextFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/DefaultLdapContextFactory.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.ldap;
+package org.apache.shiro.realm.ldap;
 
 import java.util.Hashtable;
 import java.util.Map;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapContextFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapContextFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapContextFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapContextFactory.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.ldap;
+package org.apache.shiro.realm.ldap;
 
 import javax.naming.NamingException;
 import javax.naming.ldap.LdapContext;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/LdapUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.ldap;
+package org.apache.shiro.realm.ldap;
 
 import java.util.Collection;
 import java.util.HashSet;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Realms that acquire security data from an LDAP (Lightweight Directory Access Protocol) server
- * utilizing LDAP/Naming APIs.
- */
-package org.apache.ki.realm.ldap;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Realms that acquire security data from an LDAP (Lightweight Directory Access Protocol) server
+ * utilizing LDAP/Naming APIs.
+ */
+package org.apache.shiro.realm.ldap;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/TextConfigurationRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/TextConfigurationRealm.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.text;
+package org.apache.shiro.realm.text;
 
 import java.text.ParseException;
 import java.util.Collection;
@@ -26,13 +26,13 @@
 import java.util.Scanner;
 import java.util.Set;
 
-import org.apache.ki.authc.SimpleAccount;
-import org.apache.ki.authz.Permission;
-import org.apache.ki.authz.SimpleRole;
-import org.apache.ki.realm.SimpleAccountRealm;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.util.PermissionUtils;
-import org.apache.ki.util.StringUtils;
+import org.apache.shiro.authc.SimpleAccount;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.authz.SimpleRole;
+import org.apache.shiro.realm.SimpleAccountRealm;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.util.PermissionUtils;
+import org.apache.shiro.util.StringUtils;
 
 
 /**
@@ -96,7 +96,7 @@
      * <p><code><em>rolename</em> = <em>permissionDefinition1</em>, <em>permissionDefinition2</em>, ...</code></p>
      *
      * <p>where <em>permissionDefinition</em> is an arbitrary String, but must people will want to use
-     * Strings that conform to the {@link org.apache.ki.authz.permission.WildcardPermission WildcardPermission}
+     * Strings that conform to the {@link org.apache.shiro.authz.permission.WildcardPermission WildcardPermission}
      * format for ease of use and flexibility.  Note that if an individual <em>permissionDefnition</em> needs to
      * be internally comma-delimited (e.g. <code>printer:5thFloor:print,info</code>), you will need to surround that
      * definition with double quotes (&quot;) to avoid parsing errors (e.g.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/package-info.java Thu Jun 18 03:13:34 2009
@@ -20,4 +20,4 @@
  * Realms that acquire security data from text-based data sources such as <code>File</code>s or
  * text streams.
  */
-package org.apache.ki.realm.text;
+package org.apache.shiro.realm.text;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ExpiredSessionException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ExpiredSessionException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ExpiredSessionException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ExpiredSessionException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/InvalidSessionException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/InvalidSessionException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/InvalidSessionException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/InvalidSessionException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ProxiedSession.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ProxiedSession.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ProxiedSession.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ProxiedSession.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 import java.net.InetAddress;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ReplacedSessionException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ReplacedSessionException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ReplacedSessionException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/ReplacedSessionException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/Session.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/Session.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionException.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -30,7 +30,8 @@
  * @author Les Hazlewood
  * @since 0.1
  */
-public class SessionException extends KiException {
+public class SessionException extends ShiroException
+{
 
     private Serializable sessionId;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListener.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListener.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListener.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListener.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 /**
  * Interface to be implemented by components that wish to be notified of events that occur during a 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListenerRegistrar.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListenerRegistrar.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListenerRegistrar.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionListenerRegistrar.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.util.Collection;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/StoppedSessionException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/StoppedSessionException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/StoppedSessionException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/StoppedSessionException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/UnknownSessionException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/UnknownSessionException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/UnknownSessionException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/UnknownSessionException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractSessionManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractSessionManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractSessionManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractSessionManager.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.HostUnauthorizedException;
-import org.apache.ki.session.*;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.HostUnauthorizedException;
+import org.apache.shiro.session.*;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractValidatingSessionManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractValidatingSessionManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DefaultSessionManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DefaultSessionManager.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.cache.CacheManagerAware;
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.mgt.eis.MemorySessionDAO;
-import org.apache.ki.session.mgt.eis.SessionDAO;
-import org.apache.ki.session.mgt.eis.SessionDAOAware;
-import org.apache.ki.util.CollectionUtils;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.cache.CacheManagerAware;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.mgt.eis.MemorySessionDAO;
+import org.apache.shiro.session.mgt.eis.SessionDAO;
+import org.apache.shiro.session.mgt.eis.SessionDAOAware;
+import org.apache.shiro.util.CollectionUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -109,7 +109,7 @@
     /**
      * Persists the given session instance to an underlying EIS (Enterprise Information System).  This implementation
      * delegates and calls
-     * <code>this.{@link SessionDAO sessionDAO}.{@link SessionDAO#create(org.apache.ki.session.Session) create}(session);<code>
+     * <code>this.{@link SessionDAO sessionDAO}.{@link SessionDAO#create(org.apache.shiro.session.Session) create}(session);<code>
      *
      * @param session the Session instance to persist to the underlying EIS.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DelegatingSession.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DelegatingSession.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DelegatingSession.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DelegatingSession.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -24,13 +24,13 @@
 import java.util.Date;
 import java.util.Collections;
 
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.ReplacedSessionException;
-import org.apache.ki.session.Session;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.ReplacedSessionException;
+import org.apache.shiro.session.Session;
 
 /**
  * A DelegatingSession is a client-tier representation of a server side
- * {@link org.apache.ki.session.Session Session}.
+ * {@link org.apache.shiro.session.Session Session}.
  * This implementation is basically a proxy to a server-side {@link SessionManager SessionManager},
  * which will return the proper results for each method call.
  * <p/>
@@ -109,12 +109,12 @@
         this.id = id;
     }
 
-    /** @see org.apache.ki.session.Session#getId() */
+    /** @see org.apache.shiro.session.Session#getId() */
     public Serializable getId() {
         return id;
     }
 
-    /** @see org.apache.ki.session.Session#getStartTimestamp() */
+    /** @see org.apache.shiro.session.Session#getStartTimestamp() */
     public Date getStartTimestamp() {
         if (startTimestamp == null) {
             try {
@@ -127,7 +127,7 @@
         return startTimestamp;
     }
 
-    /** @see org.apache.ki.session.Session#getLastAccessTime() */
+    /** @see org.apache.shiro.session.Session#getLastAccessTime() */
     public Date getLastAccessTime() {
         //can't cache - only business pojo knows the accurate time:
         try {
@@ -156,7 +156,7 @@
         }
     }
 
-    /** @see org.apache.ki.session.Session#getHostAddress() */
+    /** @see org.apache.shiro.session.Session#getHostAddress() */
     public InetAddress getHostAddress() {
         if (hostAddress == null) {
             try {
@@ -169,7 +169,7 @@
         return hostAddress;
     }
 
-    /** @see org.apache.ki.session.Session#touch() */
+    /** @see org.apache.shiro.session.Session#touch() */
     public void touch() throws InvalidSessionException {
         try {
             sessionManager.touch(id);
@@ -179,7 +179,7 @@
         }
     }
 
-    /** @see org.apache.ki.session.Session#stop() */
+    /** @see org.apache.shiro.session.Session#stop() */
     public void stop() throws InvalidSessionException {
         try {
             sessionManager.stop(id);
@@ -190,7 +190,7 @@
         }
     }
 
-    /** @see org.apache.ki.session.Session#getAttributeKeys */
+    /** @see org.apache.shiro.session.Session#getAttributeKeys */
     @SuppressWarnings({"unchecked"})
     public Collection<Object> getAttributeKeys() throws InvalidSessionException {
         try {
@@ -202,7 +202,7 @@
         }
     }
 
-    /** @see org.apache.ki.session.Session#getAttribute(Object key) */
+    /** @see org.apache.shiro.session.Session#getAttribute(Object key) */
     public Object getAttribute(Object key) throws InvalidSessionException {
         try {
             return sessionManager.getAttribute(id, key);

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ExecutorServiceSessionValidationScheduler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ExecutorServiceSessionValidationScheduler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ExecutorServiceSessionValidationScheduler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ExecutorServiceSessionValidationScheduler.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ImmutableProxiedSession.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ImmutableProxiedSession.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ImmutableProxiedSession.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ImmutableProxiedSession.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.ProxiedSession;
-import org.apache.ki.session.Session;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.ProxiedSession;
+import org.apache.shiro.session.Session;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/LocalSessionManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/LocalSessionManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/LocalSessionManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/LocalSessionManager.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.session.Session;
+import org.apache.shiro.session.Session;
 
 /**
  * A {@code SessionManager} that is available in a local VM only.  It is not intended to be accessible

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthenticatingRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthenticatingRealm.java Thu Jun 18 03:13:34 2009
@@ -16,22 +16,22 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.IncorrectCredentialsException;
-import org.apache.ki.authc.LogoutAware;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.authc.credential.AllowAllCredentialsMatcher;
-import org.apache.ki.authc.credential.CredentialsMatcher;
-import org.apache.ki.authc.credential.SimpleCredentialsMatcher;
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.IncorrectCredentialsException;
+import org.apache.shiro.authc.LogoutAware;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.authc.credential.AllowAllCredentialsMatcher;
+import org.apache.shiro.authc.credential.CredentialsMatcher;
+import org.apache.shiro.authc.credential.SimpleCredentialsMatcher;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.subject.PrincipalCollection;
 
 
 /**
@@ -69,7 +69,7 @@
 
     /**
      * The class that this realm supports for authentication tokens.  This is used by the
      * default implementation of the {@link Realm#supports(org.apache.ki.authc.AuthenticationToken)} method to
      * determine whether or not the given authentication token is supported by this realm.
      */
     private Class<? extends AuthenticationToken> authenticationTokenClass = UsernamePasswordToken.class;
@@ -101,7 +101,7 @@
      * credentials with those stored in the system.
      *
      * <p>Unless overridden by the {@link #setCredentialsMatcher setCredentialsMatcher} method, the default
      * value is a {@link org.apache.ki.authc.credential.SimpleCredentialsMatcher SimpleCredentialsMatcher} instance.
      *
      * @return the <code>CredentialsMatcher</code> used during an authentication attempt to verify submitted
      *         credentials with those stored in the system.
@@ -116,7 +116,7 @@
      * support any number of schemes, including plain text comparisons, hashing comparisons, and others.
      *
      * <p>Unless overridden by this method, the default value is a
-     * {@link org.apache.ki.authc.credential.SimpleCredentialsMatcher} instance.
+     * {@link org.apache.shiro.authc.credential.SimpleCredentialsMatcher} instance.
      *
      * @param credentialsMatcher the matcher to use.
      */
@@ -127,7 +127,7 @@
     /**
      * Returns the authenticationToken class supported by this realm.
      *
      * <p>The default value is <tt>{@link org.apache.ki.authc.UsernamePasswordToken UsernamePasswordToken.class}</tt>, since
      * about 90% of realms use username/password authentication, regardless of their protocol (e.g. over jdbc, ldap,
      * kerberos, http, etc).
      *
@@ -146,7 +146,7 @@
      * Sets the authenticationToken class supported by this realm.
      *
      * <p>Unless overridden by this method, the default value is
      * {@link org.apache.ki.authc.UsernamePasswordToken UsernamePasswordToken.class} to support the majority of applications.
      *
      * @param authenticationTokenClass the class of authentication token instances supported by this realm.
      * @see #getAuthenticationTokenClass getAuthenticationTokenClass() for more explanation.
@@ -206,7 +206,7 @@
      * authentication token.
      *
      * <p>For most datasources, this means just 'pulling' authentication data for an associated subject/user and nothing
      * more and letting Ki do the rest.  But in some systems, this method could actually perform EIS specific
      * log-in logic in addition to just retrieving data - it is up to the Realm implementation.
      *
      * <p>A <tt>null</tt> return value means that no account could be associated with the specified token.
@@ -214,7 +214,7 @@
      * @param token the authentication token containing the user's principal and credentials.
      * @return an {@link AuthenticationInfo} object containing account data resulting from the
      *         authentication ONLY if the lookup is successful (i.e. account exists and is valid, etc.)
-     * @throws org.apache.ki.authc.AuthenticationException
+     * @throws org.apache.shiro.authc.AuthenticationException
      *          if there is an error acquiring data or performing
      *          realm-specific authentication logic for the specified <tt>token</tt>
      */
@@ -224,14 +224,14 @@
      * Default implementation that does nothing (no-op) and exists as a convenience mechanism in case subclasses
      * wish to override it to implement realm-specific logout logic for the given user account logging out.</p>
      * <p/>
      * In a single-realm Ki configuration (most applications), the <code>principals</code> method
      * argument will be the same as that which is contained in the <code>AuthenticationInfo</code> object returned by the
      * {@link #doGetAuthenticationInfo} method (that is, {@link AuthenticationInfo#getPrincipals info.getPrincipals()}).
      * <p/>
      * In a multi-realm Ki configuration, the given <code>principals</code> method
      * argument could contain principals returned by many realms.  Therefore the subclass implementation would need
      * to know how to extract the principal(s) relevant to only itself and ignore other realms' principals.  This is
-     * usually done by calling {@link org.apache.ki.subject.PrincipalCollection#fromRealm(String) principals.fromRealm(name)},
+     * usually done by calling {@link org.apache.shiro.subject.PrincipalCollection#fromRealm(String) principals.fromRealm(name)},
      * using the realm's own {@link Realm#getName() name}.
      *
      * @param principals the application-specific Subject/user identifier that is logging out.
@@ -69,7 +69,7 @@
     /**
      * The class that this realm supports for authentication tokens.  This is used by the
-     * default implementation of the {@link Realm#supports(org.apache.ki.authc.AuthenticationToken)} method to
+     * default implementation of the {@link Realm#supports(org.apache.shiro.authc.AuthenticationToken)} method to
      * determine whether or not the given authentication token is supported by this realm.
      */
@@ -101,7 +101,7 @@
      *
      * <p>Unless overridden by the {@link #setCredentialsMatcher setCredentialsMatcher} method, the default
-     * value is a {@link org.apache.ki.authc.credential.SimpleCredentialsMatcher SimpleCredentialsMatcher} instance.
+     * value is a {@link org.apache.shiro.authc.credential.SimpleCredentialsMatcher SimpleCredentialsMatcher} instance.
      *
      * @return the <code>CredentialsMatcher</code> used during an authentication attempt to verify submitted
@@ -127,7 +127,7 @@
      * Returns the authenticationToken class supported by this realm.
      *
-     * <p>The default value is <tt>{@link org.apache.ki.authc.UsernamePasswordToken UsernamePasswordToken.class}</tt>, since
+     * <p>The default value is <tt>{@link org.apache.shiro.authc.UsernamePasswordToken UsernamePasswordToken.class}</tt>, since
      * about 90% of realms use username/password authentication, regardless of their protocol (e.g. over jdbc, ldap,
      * kerberos, http, etc).
@@ -146,7 +146,7 @@
      *
      * <p>Unless overridden by this method, the default value is
-     * {@link org.apache.ki.authc.UsernamePasswordToken UsernamePasswordToken.class} to support the majority of applications.
+     * {@link org.apache.shiro.authc.UsernamePasswordToken UsernamePasswordToken.class} to support the majority of applications.
      *
      * @param authenticationTokenClass the class of authentication token instances supported by this realm.
@@ -206,7 +206,7 @@
      *
      * <p>For most datasources, this means just 'pulling' authentication data for an associated subject/user and nothing
-     * more and letting Ki do the rest.  But in some systems, this method could actually perform EIS specific
+     * more and letting Shiro do the rest.  But in some systems, this method could actually perform EIS specific
      * log-in logic in addition to just retrieving data - it is up to the Realm implementation.
      *
@@ -224,14 +224,14 @@
      * wish to override it to implement realm-specific logout logic for the given user account logging out.</p>
      * <p/>
-     * In a single-realm Ki configuration (most applications), the <code>principals</code> method
+     * In a single-realm Shiro configuration (most applications), the <code>principals</code> method
      * argument will be the same as that which is contained in the <code>AuthenticationInfo</code> object returned by the
      * {@link #doGetAuthenticationInfo} method (that is, {@link AuthenticationInfo#getPrincipals info.getPrincipals()}).
@@ -224,14 +224,14 @@
      * {@link #doGetAuthenticationInfo} method (that is, {@link AuthenticationInfo#getPrincipals info.getPrincipals()}).
      * <p/>
-     * In a multi-realm Ki configuration, the given <code>principals</code> method
+     * In a multi-realm Shiro configuration, the given <code>principals</code> method
      * argument could contain principals returned by many realms.  Therefore the subclass implementation would need
      * to know how to extract the principal(s) relevant to only itself and ignore other realms' principals.  This is

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthorizingRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthorizingRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthorizingRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/AuthorizingRealm.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
-import org.apache.ki.authc.credential.CredentialsMatcher;
-import org.apache.ki.authz.*;
-import org.apache.ki.authz.permission.PermissionResolver;
-import org.apache.ki.authz.permission.PermissionResolverAware;
-import org.apache.ki.authz.permission.WildcardPermissionResolver;
-import org.apache.ki.cache.Cache;
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.util.Initializable;
+import org.apache.shiro.authc.credential.CredentialsMatcher;
+import org.apache.shiro.authz.*;
+import org.apache.shiro.authz.permission.PermissionResolver;
+import org.apache.shiro.authz.permission.PermissionResolverAware;
+import org.apache.shiro.authz.permission.WildcardPermissionResolver;
+import org.apache.shiro.cache.Cache;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.util.Initializable;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -39,19 +39,19 @@
  * <p/>
  * This implementation will perform all role and permission checks automatically (and subclasses do not have to
  * write this logic) as long as the
  * {@link #getAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)} method returns an
  * {@link AuthorizationInfo}.  Please see that method's JavaDoc for an in-depth explanation.
  * <p/>
  * If you find that you do not want to utilize the {@link AuthorizationInfo AuthorizationInfo} construct,
  * you are of course free to subclass the {@link AuthenticatingRealm AuthenticatingRealm} directly instead and
  * implement the remaining Realm interface methods directly.  You might do this if you want have better control
  * over how the Role and Permission checks occur for your specific data source.  However, using AuthorizationInfo
  * (and its default implementation {@link org.apache.ki.authz.SimpleAuthorizationInfo SimpleAuthorizationInfo}) is sufficient in the large
  * majority of Realm cases.
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
- * @see org.apache.ki.authz.SimpleAuthorizationInfo
+ * @see org.apache.shiro.authz.SimpleAuthorizationInfo
  * @since 0.2
  */
 public abstract class AuthorizingRealm extends AuthenticatingRealm implements Initializable, PermissionResolverAware {
@@ -146,8 +146,8 @@
      * the {@link #setCacheManager cacheManager} property will be checked.
      * If a <tt>cacheManager</tt> has been set, it will be used to create an authorization
      * <tt>cache</tt>, and this newly created cache which will be used as specified in #1.</li>
-     * <li>If neither the {@link #setAuthorizationCache (org.apache.ki.cache.Cache) cache}
-     * or {@link #setCacheManager(org.apache.ki.cache.CacheManager) cacheManager}
+     * <li>If neither the {@link #setAuthorizationCache (org.apache.shiro.cache.Cache) cache}
+     * or {@link #setCacheManager(org.apache.shiro.cache.CacheManager) cacheManager}
      * properties are set, caching will be disabled and authorization lookups will be delegated to
      * subclass implementations for each authorization check.</li>
      * </ol>
@@ -210,11 +210,11 @@
      * <p/>
      * This implementation obtains the actual <code>AuthorizationInfo</code> object from the subclass's
      * implementation of
-     * {@link #doGetAuthorizationInfo(org.apache.ki.subject.PrincipalCollection) doGetAuthorizationInfo}, and then
+     * {@link #doGetAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection) doGetAuthorizationInfo}, and then
      * caches it for efficient reuse if caching is enabled (see below).
      * <p/>
      * Invocations of this method should be thought of as completely orthogonal to acquiring
      * {@link #getAuthenticationInfo(org.apache.ki.authc.AuthenticationToken) authenticationInfo}, since either could
      * occur in any order.
      * <p/>
      * For example, in &quot;Remember Me&quot; scenarios, the user identity is remembered (and
@@ -231,12 +231,12 @@
      * If caching is enabled, the authorization cache will be checked first and if found, will return the cached
      * <code>AuthorizationInfo</code> immediately.  If caching is disabled, or there is a cache miss from the cache
      * lookup, the authorization info will be looked up from the underlying data store via the
      * {@link #doGetAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)} method, which must be implemented by subclasses.
      * <p/>
      * <b>Please note:</b>  If caching is enabled and if any authorization data for an account is changed at
      * runtime, such as adding or removing roles and/or permissions, the subclass imlementation should clear the
      * cached AuthorizationInfo for that account via the
-     * {@link #clearCachedAuthorizationInfo(org.apache.ki.subject.PrincipalCollection) clearCachedAuthorizationInfo}
+     * {@link #clearCachedAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection) clearCachedAuthorizationInfo}
      * method.  This ensures that the next call to <code>getAuthorizationInfo(PrincipalCollection)</code> will
      * acquire the account's fresh authorization data, where it will then be cached for efficient reuse.  This
      * ensures that stale authorization data will not be reused.
@@ -304,7 +304,7 @@
      * subsequent authorization operations don't used the (old) cached value if account data changes.
      * <p/>
      * After this method is called, the next authorization check for that same account will result in a call to
-     * {@link #getAuthorizationInfo(org.apache.ki.subject.PrincipalCollection) getAuthorizationInfo}, and the
+     * {@link #getAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection) getAuthorizationInfo}, and the
      * resulting return value will be cached before being returned so it can be reused for later authorization checks.
      *
      * @param principals the principals of the account for which to clear the cached AuthorizationInfo.
@@ -325,11 +325,11 @@
     /**
      * Retrieves the AuthorizationInfo for the given principals from the underlying data store.  When returning
      * an instance from this method, you might want to consider using an instance of
      * {@link org.apache.ki.authz.SimpleAuthorizationInfo SimpleAuthorizationInfo}, as it is suitable in most cases.
      *
      * @param principals the primary identifying principals of the AuthorizationInfo that should be retrieved.
      * @return the AuthorizationInfo associated with this principals.
-     * @see org.apache.ki.authz.SimpleAuthorizationInfo
+     * @see org.apache.shiro.authz.SimpleAuthorizationInfo
      */
     protected abstract AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principals);
 
@@ -39,19 +39,19 @@
  * This implementation will perform all role and permission checks automatically (and subclasses do not have to
  * write this logic) as long as the
- * {@link #getAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)} method returns an
+ * {@link #getAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection)} method returns an
  * {@link AuthorizationInfo}.  Please see that method's JavaDoc for an in-depth explanation.
  * <p/>
@@ -39,19 +39,19 @@
  * implement the remaining Realm interface methods directly.  You might do this if you want have better control
  * over how the Role and Permission checks occur for your specific data source.  However, using AuthorizationInfo
- * (and its default implementation {@link org.apache.ki.authz.SimpleAuthorizationInfo SimpleAuthorizationInfo}) is sufficient in the large
+ * (and its default implementation {@link org.apache.shiro.authz.SimpleAuthorizationInfo SimpleAuthorizationInfo}) is sufficient in the large
  * majority of Realm cases.
  *
@@ -210,11 +210,11 @@
      * <p/>
      * Invocations of this method should be thought of as completely orthogonal to acquiring
-     * {@link #getAuthenticationInfo(org.apache.ki.authc.AuthenticationToken) authenticationInfo}, since either could
+     * {@link #getAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken) authenticationInfo}, since either could
      * occur in any order.
      * <p/>
@@ -231,12 +231,12 @@
      * <code>AuthorizationInfo</code> immediately.  If caching is disabled, or there is a cache miss from the cache
      * lookup, the authorization info will be looked up from the underlying data store via the
-     * {@link #doGetAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)} method, which must be implemented by subclasses.
+     * {@link #doGetAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection)} method, which must be implemented by subclasses.
      * <p/>
      * <b>Please note:</b>  If caching is enabled and if any authorization data for an account is changed at
@@ -325,11 +325,11 @@
      * Retrieves the AuthorizationInfo for the given principals from the underlying data store.  When returning
      * an instance from this method, you might want to consider using an instance of
-     * {@link org.apache.ki.authz.SimpleAuthorizationInfo SimpleAuthorizationInfo}, as it is suitable in most cases.
+     * {@link org.apache.shiro.authz.SimpleAuthorizationInfo SimpleAuthorizationInfo}, as it is suitable in most cases.
      *
      * @param principals the primary identifying principals of the AuthorizationInfo that should be retrieved.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/CachingRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/CachingRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/Realm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/Realm.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authz.Authorizer;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authz.Authorizer;
 
 
 /**
@@ -39,29 +39,29 @@
  * <a href="http://en.wikipedia.org/wiki/Pluggable_Authentication_Modules">PAM</a> configuration.  This allows a Realm to
  * perform <i>both</i> authentication and authorization duties for a single datasource, which caters to the large
  * majority of applications.  If for some reason you don't want your Realm implementation to perform authentication
  * duties, you should override the {@link #supports(org.apache.ki.authc.AuthenticationToken)} method to always
  * return <tt>false</tt>.
  *
  * <p>Because every application is different, security data such as users and roles can be
  * represented in any number of ways.  Ki tries to maintain a non-intrusive development philosophy whenever
  * possible - it does not require you to implement or extend any <tt>User</tt>, <tt>Group</tt> or <tt>Role</tt>
  * interfaces or classes.
  *
  * <p>Instead, Ki allows applications to implement this interface to access environment-specific datasources
  * and data model objects.  The implementation can then be plugged in to the application's Ki configuration.
  * This modular technique abstracts away any environment/modeling details and allows Ki to be deployed in
  * practically any application environment.
  *
  * <p>Most users will not implement the <tt>Realm</tt> interface directly, but will extend one of the subclasses,
  * {@link org.apache.ki.realm.AuthenticatingRealm AuthenticatingRealm} or {@link org.apache.ki.realm.AuthorizingRealm}, greatly reducing the effort requird
  * to implement a <tt>Realm</tt> from scratch.</p>
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
  * @see org.apache.ki.realm.CachingRealm CachingRealm
  * @see org.apache.ki.realm.AuthenticatingRealm AuthenticatingRealm
  * @see org.apache.ki.realm.AuthorizingRealm AuthorizingRealm
  * @see org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator
  * @since 0.1
  */
 public interface Realm extends Authorizer {
@@ -76,7 +76,7 @@
 
     /**
      * Returns <tt>true</tt> if this realm wishes to authenticate the Subject represented by the given
      * {@link org.apache.ki.authc.AuthenticationToken AuthenticationToken} instance, <tt>false</tt> otherwise.
      *
      * <p>If this method returns <tt>false</tt>, it will not be called to authenticate the Subject represented by
      * the token - more specifically, a <tt>false</tt> return value means this Realm instance's
@@ -94,13 +94,13 @@
      *
      * <p>This method effectively represents a login attempt for the corresponding user with the underlying EIS datasource.
      * Most implementations merely just need to lookup and return the account data only (as the method name implies)
      * and let Ki do the rest, but implementations may of course perform eis specific login operations if so
      * desired.
      *
      * @param token the application-specific representation of an account principal and credentials.
      * @return the authentication information for the account associated with the specified <tt>token</tt>,
      *         or <tt>null</tt> if no account could be found.
-     * @throws org.apache.ki.authc.AuthenticationException
+     * @throws org.apache.shiro.authc.AuthenticationException
      *          if there is an error obtaining or constructing an AuthenticationInfo object based on the
      *          specified <tt>token</tt> or implementation-specifc login behavior fails.
      */
@@ -39,29 +39,29 @@
  * perform <i>both</i> authentication and authorization duties for a single datasource, which caters to the large
  * majority of applications.  If for some reason you don't want your Realm implementation to perform authentication
- * duties, you should override the {@link #supports(org.apache.ki.authc.AuthenticationToken)} method to always
+ * duties, you should override the {@link #supports(org.apache.shiro.authc.AuthenticationToken)} method to always
  * return <tt>false</tt>.
  *
@@ -39,29 +39,29 @@
  *
  * <p>Because every application is different, security data such as users and roles can be
- * represented in any number of ways.  Ki tries to maintain a non-intrusive development philosophy whenever
+ * represented in any number of ways.  Shiro tries to maintain a non-intrusive development philosophy whenever
  * possible - it does not require you to implement or extend any <tt>User</tt>, <tt>Group</tt> or <tt>Role</tt>
  * interfaces or classes.
@@ -39,29 +39,29 @@
  * interfaces or classes.
  *
- * <p>Instead, Ki allows applications to implement this interface to access environment-specific datasources
- * and data model objects.  The implementation can then be plugged in to the application's Ki configuration.
- * This modular technique abstracts away any environment/modeling details and allows Ki to be deployed in
+ * <p>Instead, Shiro allows applications to implement this interface to access environment-specific datasources
+ * and data model objects.  The implementation can then be plugged in to the application's Shiro configuration.
+ * This modular technique abstracts away any environment/modeling details and allows Shiro to be deployed in
  * practically any application environment.
  *
@@ -39,29 +39,29 @@
  *
  * <p>Most users will not implement the <tt>Realm</tt> interface directly, but will extend one of the subclasses,
- * {@link org.apache.ki.realm.AuthenticatingRealm AuthenticatingRealm} or {@link org.apache.ki.realm.AuthorizingRealm}, greatly reducing the effort requird
+ * {@link org.apache.shiro.realm.AuthenticatingRealm AuthenticatingRealm} or {@link org.apache.shiro.realm.AuthorizingRealm}, greatly reducing the effort requird
  * to implement a <tt>Realm</tt> from scratch.</p>
  *
@@ -39,29 +39,29 @@
  * @author Les Hazlewood
  * @author Jeremy Haile
- * @see org.apache.ki.realm.CachingRealm CachingRealm
- * @see org.apache.ki.realm.AuthenticatingRealm AuthenticatingRealm
- * @see org.apache.ki.realm.AuthorizingRealm AuthorizingRealm
- * @see org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator
+ * @see org.apache.shiro.realm.CachingRealm CachingRealm
+ * @see org.apache.shiro.realm.AuthenticatingRealm AuthenticatingRealm
+ * @see org.apache.shiro.realm.AuthorizingRealm AuthorizingRealm
+ * @see org.apache.shiro.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator
  * @since 0.1
  */
@@ -76,7 +76,7 @@
     /**
      * Returns <tt>true</tt> if this realm wishes to authenticate the Subject represented by the given
-     * {@link org.apache.ki.authc.AuthenticationToken AuthenticationToken} instance, <tt>false</tt> otherwise.
+     * {@link org.apache.shiro.authc.AuthenticationToken AuthenticationToken} instance, <tt>false</tt> otherwise.
      *
      * <p>If this method returns <tt>false</tt>, it will not be called to authenticate the Subject represented by
@@ -94,13 +94,13 @@
      * <p>This method effectively represents a login attempt for the corresponding user with the underlying EIS datasource.
      * Most implementations merely just need to lookup and return the account data only (as the method name implies)
-     * and let Ki do the rest, but implementations may of course perform eis specific login operations if so
+     * and let Shiro do the rest, but implementations may of course perform eis specific login operations if so
      * desired.
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/RealmFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/RealmFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/RealmFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/RealmFactory.java Thu Jun 18 03:13:34 2009
@@ -16,21 +16,21 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
 import java.util.Collection;
 
 /**
  * Enables Ki end-users to configure and initialize one or more {@link Realm Realm} instances
  * in any manner desired.
  * <p/>
  * This interface exists to support environments where end-users may not wish to use Ki's default
  * text-based configuration to create and configure realms, and instead wish to retrieve a realm configured in a
  * proprietary manner.  An implementation of this interface can access that proprietary mechanism to retrieve the
  * already-created <tt>Realm</tt>s.
  *
  * <p>The <code>Realm</code> instances returned will used to construct the application's
- * {@link org.apache.ki.mgt.SecurityManager SecurityManager} instance.
+ * {@link org.apache.shiro.mgt.SecurityManager SecurityManager} instance.
  *
  * @since 0.9
  */
@@ -40,7 +40,7 @@
      * Returns a collection of {@link Realm Realm} instances that will be used to construct
      * the application's SecurityManager instance.
      *
-     * <p>The order of the collection is important.  The {@link org.apache.ki.mgt.SecurityManager SecurityManager}
+     * <p>The order of the collection is important.  The {@link org.apache.shiro.mgt.SecurityManager SecurityManager}
      * implementation will consult the Realms during authentication (log-in) and authorization (access control)
      * operations in the collection's <b>iteration order</b>.  That is, the resulting collection's
      * {@link java.util.Iterator Iterator} determines the order in which Realms are used.
@@ -16,21 +16,21 @@
 
 /**
- * Enables Ki end-users to configure and initialize one or more {@link Realm Realm} instances
+ * Enables Shiro end-users to configure and initialize one or more {@link Realm Realm} instances
  * in any manner desired.
  * <p/>
@@ -16,21 +16,21 @@
  * in any manner desired.
  * <p/>
- * This interface exists to support environments where end-users may not wish to use Ki's default
+ * This interface exists to support environments where end-users may not wish to use Shiro's default
  * text-based configuration to create and configure realms, and instead wish to retrieve a realm configured in a
  * proprietary manner.  An implementation of this interface can access that proprietary mechanism to retrieve the

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/SimpleAccountRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/SimpleAccountRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/SimpleAccountRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/SimpleAccountRealm.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
-import org.apache.ki.authc.*;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.authz.SimpleAuthorizingAccount;
-import org.apache.ki.authz.SimpleRole;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.util.CollectionUtils;
+import org.apache.shiro.authc.*;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.authz.SimpleAuthorizingAccount;
+import org.apache.shiro.authz.SimpleRole;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.util.CollectionUtils;
 
 import java.util.HashMap;
 import java.util.HashSet;
@@ -37,7 +37,7 @@
  * specifies the username, password, and roles for a user.  Roles can also be mapped
  * to permissions and associated with users.</p>
  * <p/>
  * <p>User accounts and roles are stored in two {@link org.apache.ki.cache.Cache cache}s, so it is the Cache manager implementation that
  * determines if this class stores all data in memory or spools to disk or clusters it, etc based on the
  * Caches it creates.
  *
@@ -37,7 +37,7 @@
  * to permissions and associated with users.</p>
  * <p/>
- * <p>User accounts and roles are stored in two {@link org.apache.ki.cache.Cache cache}s, so it is the Cache manager implementation that
+ * <p>User accounts and roles are stored in two {@link org.apache.shiro.cache.Cache cache}s, so it is the Cache manager implementation that
  * determines if this class stores all data in memory or spools to disk or clusters it, etc based on the
  * Caches it creates.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealm.java Thu Jun 18 03:13:34 2009
@@ -16,19 +16,19 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.activedirectory;
+package org.apache.shiro.realm.activedirectory;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.SimpleAuthenticationInfo;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.authz.SimpleAuthorizationInfo;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.realm.ldap.AbstractLdapRealm;
-import org.apache.ki.realm.ldap.LdapContextFactory;
-import org.apache.ki.realm.ldap.LdapUtils;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.SimpleAuthenticationInfo;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.authz.SimpleAuthorizationInfo;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.realm.ldap.AbstractLdapRealm;
+import org.apache.shiro.realm.ldap.LdapContextFactory;
+import org.apache.shiro.realm.ldap.LdapUtils;
+import org.apache.shiro.subject.PrincipalCollection;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -121,7 +121,7 @@
 
 
     /**
      * Builds an {@link org.apache.ki.authz.AuthorizationInfo} object by querying the active directory LDAP context for the
      * groups that a user is a member of.  The groups are then translated to role names by using the
      * configured {@link #groupRolesMap}.
      * <p/>
@@ -121,7 +121,7 @@
 
     /**
-     * Builds an {@link org.apache.ki.authz.AuthorizationInfo} object by querying the active directory LDAP context for the
+     * Builds an {@link org.apache.shiro.authz.AuthorizationInfo} object by querying the active directory LDAP context for the
      * groups that a user is a member of.  The groups are then translated to role names by using the
      * configured {@link #groupRolesMap}.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/activedirectory/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/JdbcRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/JdbcRealm.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.jdbc;
+package org.apache.shiro.realm.jdbc;
 
-import org.apache.ki.authc.*;
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.authz.SimpleAuthorizationInfo;
-import org.apache.ki.realm.AuthorizingRealm;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.util.JdbcUtils;
+import org.apache.shiro.authc.*;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.authz.SimpleAuthorizationInfo;
+import org.apache.shiro.realm.AuthorizingRealm;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.util.JdbcUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -45,10 +45,10 @@
  * <p/>
  * If the default implementation
  * of authentication and authorization cannot handle your schema, this class can be subclassed and the
  * appropriate methods overridden. (usually {@link #doGetAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)},
  * {@link #getRoleNamesForUser(java.sql.Connection,String)}, and/or {@link #getPermissions(java.sql.Connection,String,java.util.Collection)}
  * <p/>
  * This realm supports caching by extending from {@link org.apache.ki.realm.AuthorizingRealm}.
  *
  * @author Jeremy Haile
  * @since 0.2
@@ -111,7 +111,7 @@
      * Overrides the default query used to retrieve a user's password during authentication.  When using the default
      * implementation, this query must take the user's username as a single parameter and return a single result
      * with the user's password as the first column.  If you require a solution that does not match this query
      * structure, you can override {@link #doGetAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)} or
      * just {@link #getPasswordForUser(java.sql.Connection,String)}
      *
      * @param authenticationQuery the query to use for authentication.
@@ -140,7 +140,7 @@
      * implementation, this query must take a role name as the single parameter and return a row
      * per permission with three columns containing the fully qualified name of the permission class, the permission
      * name, and the permission actions (in that order).  If you require a solution that does not match this query
      * structure, you can override {@link #doGetAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)} or just
      * {@link #getPermissions(java.sql.Connection,String,java.util.Collection)}</p>
      * <p/>
      * <b>Permissions are only retrieved if you set {@link #permissionsLookupEnabled} to true.  Otherwise,
@@ -248,7 +248,7 @@
      * This implementation of the interface expects the principals collection to return a String username keyed off of
      * this realm's {@link #getName() name}
      *
-     * @see #getAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)
+     * @see #getAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection)
      */
     @Override
     protected AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principals) {
@@ -45,10 +45,10 @@
  * If the default implementation
  * of authentication and authorization cannot handle your schema, this class can be subclassed and the
- * appropriate methods overridden. (usually {@link #doGetAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)},
+ * appropriate methods overridden. (usually {@link #doGetAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken)},
  * {@link #getRoleNamesForUser(java.sql.Connection,String)}, and/or {@link #getPermissions(java.sql.Connection,String,java.util.Collection)}
  * <p/>
@@ -45,10 +45,10 @@
  * {@link #getRoleNamesForUser(java.sql.Connection,String)}, and/or {@link #getPermissions(java.sql.Connection,String,java.util.Collection)}
  * <p/>
- * This realm supports caching by extending from {@link org.apache.ki.realm.AuthorizingRealm}.
+ * This realm supports caching by extending from {@link org.apache.shiro.realm.AuthorizingRealm}.
  *
  * @author Jeremy Haile
@@ -111,7 +111,7 @@
      * implementation, this query must take the user's username as a single parameter and return a single result
      * with the user's password as the first column.  If you require a solution that does not match this query
-     * structure, you can override {@link #doGetAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)} or
+     * structure, you can override {@link #doGetAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken)} or
      * just {@link #getPasswordForUser(java.sql.Connection,String)}
      *
@@ -140,7 +140,7 @@
      * per permission with three columns containing the fully qualified name of the permission class, the permission
      * name, and the permission actions (in that order).  If you require a solution that does not match this query
-     * structure, you can override {@link #doGetAuthorizationInfo(org.apache.ki.subject.PrincipalCollection)} or just
+     * structure, you can override {@link #doGetAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection)} or just
      * {@link #getPermissions(java.sql.Connection,String,java.util.Collection)}</p>
      * <p/>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jdbc/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/jndi/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,5 +17,5 @@
  * under the License.
  */
 /**
- * Support for acquiring Realms from JNDI, particularly useful for configuring Ki in JEE or EJB environments. */
-package org.apache.ki.realm.jndi;
+ * Support for acquiring Realms from JNDI, particularly useful for configuring Shiro in JEE or EJB environments. */
+package org.apache.shiro.realm.jndi;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/AbstractLdapRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/AbstractLdapRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/AbstractLdapRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/AbstractLdapRealm.java Thu Jun 18 03:13:34 2009
@@ -16,29 +16,29 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.ldap;
+package org.apache.shiro.realm.ldap;
 
 import javax.naming.NamingException;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.realm.AuthorizingRealm;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.realm.AuthorizingRealm;
+import org.apache.shiro.subject.PrincipalCollection;
 
 /**
  * <p>A {@link org.apache.ki.realm.Realm} that authenticates with an LDAP
  * server to build the Subject for a user.  This implementation only returns roles for a
  * particular user, and not permissions - but it can be subclassed to build a permission
  * list as well.</p>
  *
  * <p>Implementations would need to implement the
  * {@link #queryForAuthenticationInfo(org.apache.ki.authc.AuthenticationToken ,LdapContextFactory)} and
  * {@link #queryForAuthorizationInfo(org.apache.ki.subject.PrincipalCollection ,LdapContextFactory)} abstract methods.</p>
  *
  * <p>By default, this implementation will create an instance of {@link DefaultLdapContextFactory} to use for
  * creating LDAP connections using the principalSuffix, searchBase, url, systemUsername, and systemPassword properties
@@ -48,8 +48,8 @@
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see #queryForAuthenticationInfo(org.apache.ki.authc.AuthenticationToken , LdapContextFactory)
- * @see #queryForAuthorizationInfo(org.apache.ki.subject.PrincipalCollection , LdapContextFactory)
+ * @see #queryForAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken , LdapContextFactory)
+ * @see #queryForAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection , LdapContextFactory)
  * @since 0.1
  */
 public abstract class AbstractLdapRealm extends AuthorizingRealm {
@@ -16,29 +16,29 @@
 
 /**
- * <p>A {@link org.apache.ki.realm.Realm} that authenticates with an LDAP
+ * <p>A {@link org.apache.shiro.realm.Realm} that authenticates with an LDAP
  * server to build the Subject for a user.  This implementation only returns roles for a
  * particular user, and not permissions - but it can be subclassed to build a permission
@@ -16,29 +16,29 @@
  *
  * <p>Implementations would need to implement the
- * {@link #queryForAuthenticationInfo(org.apache.ki.authc.AuthenticationToken ,LdapContextFactory)} and
- * {@link #queryForAuthorizationInfo(org.apache.ki.subject.PrincipalCollection ,LdapContextFactory)} abstract methods.</p>
+ * {@link #queryForAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken ,LdapContextFactory)} and
+ * {@link #queryForAuthorizationInfo(org.apache.shiro.subject.PrincipalCollection ,LdapContextFactory)} abstract methods.</p>
  *
  * <p>By default, this implementation will create an instance of {@link DefaultLdapContextFactory} to use for

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/DefaultLdapContextFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/ldap/DefaultLdapContextFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,25 +1,25 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Components and sub-packages used in supporting the core {@link org.apache.ki.realm.Realm Realm} interface.
- * <p/>
- * Take particular note of the multiple sub-packages with existing Realm implementations supporting many
- * environments that you can use use directly or extend for custom behavior.
- */
-package org.apache.ki.realm;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Components and sub-packages used in supporting the core {@link org.apache.shiro.realm.Realm Realm} interface.
+ * <p/>
+ * Take particular note of the multiple sub-packages with existing Realm implementations supporting many
+ * environments that you can use use directly or extend for custom behavior.
+ */
+package org.apache.shiro.realm;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/PropertiesRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/PropertiesRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/PropertiesRealm.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/PropertiesRealm.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.text;
+package org.apache.shiro.realm.text;
 
 import java.io.File;
 import java.io.IOException;
@@ -31,10 +31,10 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.KiException;
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.io.ResourceUtils;
-import org.apache.ki.util.Destroyable;
+import org.apache.shiro.ShiroException;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.io.ResourceUtils;
+import org.apache.shiro.util.Destroyable;
 
 
 /**
@@ -45,14 +45,14 @@
  * permission configuration.
  *
  * <p>For convenience, if the {@link #setResourcePath resourcePath} attribute is not set, this class defaults to lookup
  * the properties file definition from <tt>classpath:ki-users.properties</tt> (root of the classpath).
  * This allows you to use this implementation by simply defining this file at the classpath root, instantiating this
  * class, and then calling {@link #init init()}.
  *
  * <p>Or, you may of course specify any other file path using the <tt>url:</tt>, <tt>file:</tt>, or <tt>classpath:</tt>
  * prefixes.</p>
  *
  * <p>If none of these are specified, and the ki-users.properties is not included at the root of the classpath,
  * a default failsafe configuration will be used.  This is not recommended as it only contains a few simple users and
  * roles which are probably of little value to production applications.</p>
  *
@@ -83,7 +83,7 @@
  * user.abrown = <em>abrownPassword</em>,qa,employee<br/>
  * user.djones = <em>djonesPassword</em>,qa,contractor<br/>
  * <br/>
- * role.administrator = org.apache.ki.authz.support.AllPermission<br/>
+ * role.administrator = org.apache.shiro.authz.support.AllPermission<br/>
  * role.manager = com.domain.UserPermission,*,read,write;com.domain.FilePermission,/usr/local/emailManagers.sh,execute<br/>
  * role.engineer = com.domain.FilePermission,/usr/local/tomcat/bin/startup.sh,read,execute<br/>
  * role.employee = com.domain.IntranetPermission,useWiki<br/>
@@ -104,8 +104,8 @@
     private static final int DEFAULT_RELOAD_INTERVAL_SECONDS = 10;
     private static final String USERNAME_PREFIX = "user.";
     private static final String ROLENAME_PREFIX = "role.";
-    private static final String DEFAULT_RESOURCE_PATH = "classpath:ki-users.properties";
-    private static final String FAILSAFE_RESOURCE_PATH = "classpath:org/apache/ki/realm/text/default-ki-users.properties";
+    private static final String DEFAULT_RESOURCE_PATH = "classpath:shiro-users.properties";
+    private static final String FAILSAFE_RESOURCE_PATH = "classpath:org/apache/shiro/realm/text/default-shiro-users.properties";
 
     /*--------------------------------------------
     |    I N S T A N C E   V A R I A B L E S    |
@@ -135,8 +135,8 @@
             loadProperties();
         } catch (Exception e) {
             if (log.isInfoEnabled()) {
-                log.info("Unable to find a ki-users.properties file at location [" + this.resourcePath + "].  " +
-                        "Defaulting to Ki's failsafe properties file (demo use only).");
+                log.info("Unable to find a shiro-users.properties file at location [" + this.resourcePath + "].  " +
+                        "Defaulting to Shiro's failsafe properties file (demo use only).");
             }
             this.resourcePath = FAILSAFE_RESOURCE_PATH;
             loadProperties();
@@ -261,7 +261,7 @@
             }
 
         } catch (IOException e) {
-            throw new KiException("Error reading properties path [" + resourcePath + "].  " +
+            throw new ShiroException("Error reading properties path [" + resourcePath + "].  " +
                     "Initializing of the realm from this file failed.", e);
         } finally {
             ResourceUtils.close(is);
@@ -45,14 +45,14 @@
  *
  * <p>For convenience, if the {@link #setResourcePath resourcePath} attribute is not set, this class defaults to lookup
- * the properties file definition from <tt>classpath:ki-users.properties</tt> (root of the classpath).
+ * the properties file definition from <tt>classpath:shiro-users.properties</tt> (root of the classpath).
  * This allows you to use this implementation by simply defining this file at the classpath root, instantiating this
  * class, and then calling {@link #init init()}.
@@ -45,14 +45,14 @@
  * prefixes.</p>
  *
- * <p>If none of these are specified, and the ki-users.properties is not included at the root of the classpath,
+ * <p>If none of these are specified, and the shiro-users.properties is not included at the root of the classpath,
  * a default failsafe configuration will be used.  This is not recommended as it only contains a few simple users and
  * roles which are probably of little value to production applications.</p>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/TextConfigurationRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/realm/text/TextConfigurationRealm.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/Session.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/Session.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -73,8 +73,8 @@
      * length of time.</li>
      * </ul>
      * <b>*Note:</b> if you are used to the {@code HttpSession}'s {@code getMaxInactiveInterval()} method, the scale on
      * this method is different: Ki Sessions use millisecond values for timeout whereas
      * {@code HttpSession.getMaxInactiveInterval} uses seconds.  Always use millisecond values with Ki sessions.
      *
      * @return the time in milliseconds the session may remain idle before expiring.
      * @throws InvalidSessionException if the session has been stopped or expired prior to calling this method.
@@ -91,8 +91,8 @@
      * </ul>
      * <p/>
      * <b>*Note:</b> if you are used to the {@code HttpSession}'s {@code getMaxInactiveInterval()} method, the scale on
      * this method is different: Ki Sessions use millisecond values for timeout whereas
      * {@code HttpSession.getMaxInactiveInterval} uses seconds.  Always use millisecond values with Ki sessions.
      *
      * @param maxIdleTimeInMillis the time in milliseconds that the session may remain idle before expiring.
      * @throws InvalidSessionException if the session has been stopped or expired prior to calling this method.
@@ -106,7 +106,7 @@
      *
      * @return the {@code InetAddress} of the host that originated this session, or {@code null}
      *         if the host address is unknown.
-     * @see org.apache.ki.session.mgt.SessionManager#start(java.net.InetAddress)
+     * @see org.apache.shiro.session.mgt.SessionManager#start(java.net.InetAddress)
      */
     InetAddress getHostAddress();
 
@@ -154,7 +154,7 @@
      * is explicitly stopped by application code by calling this method directly, it could clear out any
      * authentication state that might exist, thereby effectively &quot;unauthenticating&quot; the {@code Subject}.
      * <p/>
      * As such, you might consider {@link org.apache.ki.subject.Subject#logout logging-out} the 'owning'
      * {@code Subject} instead of manually calling this method, as a log out is expected to stop the
      * corresponding session automatically, and also allows framework code to execute additional cleanup logic.
      *
@@ -73,8 +73,8 @@
      * </ul>
      * <b>*Note:</b> if you are used to the {@code HttpSession}'s {@code getMaxInactiveInterval()} method, the scale on
-     * this method is different: Ki Sessions use millisecond values for timeout whereas
-     * {@code HttpSession.getMaxInactiveInterval} uses seconds.  Always use millisecond values with Ki sessions.
+     * this method is different: Shiro Sessions use millisecond values for timeout whereas
+     * {@code HttpSession.getMaxInactiveInterval} uses seconds.  Always use millisecond values with Shiro sessions.
      *
      * @return the time in milliseconds the session may remain idle before expiring.
@@ -91,8 +91,8 @@
      * <p/>
      * <b>*Note:</b> if you are used to the {@code HttpSession}'s {@code getMaxInactiveInterval()} method, the scale on
-     * this method is different: Ki Sessions use millisecond values for timeout whereas
-     * {@code HttpSession.getMaxInactiveInterval} uses seconds.  Always use millisecond values with Ki sessions.
+     * this method is different: Shiro Sessions use millisecond values for timeout whereas
+     * {@code HttpSession.getMaxInactiveInterval} uses seconds.  Always use millisecond values with Shiro sessions.
      *
      * @param maxIdleTimeInMillis the time in milliseconds that the session may remain idle before expiring.
@@ -154,7 +154,7 @@
      * authentication state that might exist, thereby effectively &quot;unauthenticating&quot; the {@code Subject}.
      * <p/>
-     * As such, you might consider {@link org.apache.ki.subject.Subject#logout logging-out} the 'owning'
+     * As such, you might consider {@link org.apache.shiro.subject.Subject#logout logging-out} the 'owning'
      * {@code Subject} instead of manually calling this method, as a log out is expected to stop the
      * corresponding session automatically, and also allows framework code to execute additional cleanup logic.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/SessionException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractValidatingSessionManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/AbstractValidatingSessionManager.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.session.ExpiredSessionException;
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.ReplacedSessionException;
-import org.apache.ki.session.Session;
-import org.apache.ki.util.Destroyable;
-import org.apache.ki.util.LifecycleUtils;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.session.ExpiredSessionException;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.ReplacedSessionException;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.util.Destroyable;
+import org.apache.shiro.util.LifecycleUtils;
+import org.apache.shiro.util.ThreadContext;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -124,7 +124,7 @@
      * convenience and to match what most people are accustomed based on years of servlet container behavior.
      * <p/>
      * When true (the default), this {@code SessionManager} implementation throws an
      * {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new session is created so
      * the caller can receive the new session ID and react accordingly for future {@code SessionManager SessionManager}
      * method invocations.
      *
@@ -141,7 +141,7 @@
      * convenience and to match what most people are accustomed based on years of servlet container behavior.
      * <p/>
      * When true (the default), this {@code SessionManager} implementation throws an
      * {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new session is created so
      * the caller can receive the new session ID and react accordingly for future {@code SessionManager SessionManager}
      * method invocations.
      *
@@ -225,9 +225,9 @@
 
     /**
      * Subclass template hook in case per-session timeout is not based on
-     * {@link org.apache.ki.session.Session#getTimeout()}.
+     * {@link org.apache.shiro.session.Session#getTimeout()}.
      * <p/>
      * <p>This implementation merely returns {@link org.apache.ki.session.Session#getTimeout()}</p>
      *
      * @param session the session for which to determine session timeout.
      * @return the time in milliseconds the specified session may remain idle before expiring.
@@ -124,7 +124,7 @@
      * <p/>
      * When true (the default), this {@code SessionManager} implementation throws an
-     * {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new session is created so
+     * {@link org.apache.shiro.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new session is created so
      * the caller can receive the new session ID and react accordingly for future {@code SessionManager SessionManager}
      * method invocations.
@@ -141,7 +141,7 @@
      * <p/>
      * When true (the default), this {@code SessionManager} implementation throws an
-     * {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new session is created so
+     * {@link org.apache.shiro.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new session is created so
      * the caller can receive the new session ID and react accordingly for future {@code SessionManager SessionManager}
      * method invocations.
@@ -225,9 +225,9 @@
      * <p/>
-     * <p>This implementation merely returns {@link org.apache.ki.session.Session#getTimeout()}</p>
+     * <p>This implementation merely returns {@link org.apache.shiro.session.Session#getTimeout()}</p>
      *
      * @param session the session for which to determine session timeout.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DefaultSessionManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/DefaultSessionManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactory.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.session.Session;
+import org.apache.shiro.session.Session;
 
 import java.net.InetAddress;
 import java.util.Map;
@@ -26,8 +26,8 @@
 /**
  * A simple factory class that instantiates concrete {@link Session Session} instances.  This is mainly a
  * mechanism to allow instances to be created at runtime if they need to be different the
  * defaults.  It is not used by end-users of the framework, but rather those configuring Ki to work in an
  * application, and is typically injected into the {@link org.apache.ki.mgt.SecurityManager SecurityManager} or a
  * {@link SessionManager}.
  *
  * @author Les Hazlewood
@@ -26,8 +26,8 @@
  * A simple factory class that instantiates concrete {@link Session Session} instances.  This is mainly a
  * mechanism to allow instances to be created at runtime if they need to be different the
- * defaults.  It is not used by end-users of the framework, but rather those configuring Ki to work in an
- * application, and is typically injected into the {@link org.apache.ki.mgt.SecurityManager SecurityManager} or a
+ * defaults.  It is not used by end-users of the framework, but rather those configuring Shiro to work in an
+ * application, and is typically injected into the {@link org.apache.shiro.mgt.SecurityManager SecurityManager} or a
  * {@link SessionManager}.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactoryAware.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactoryAware.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactoryAware.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionFactoryAware.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
 /**
  * Allows interested components to receive a configured {@link SessionFactory} instance.
@@ -27,9 +27,9 @@
 public interface SessionFactoryAware {
 
     /**
      * Sets the session factory to use to generate {@link org.apache.ki.session.Session Session}s.
      *
      * @param sessionFactory the session factory to use to generate {@link org.apache.ki.session.Session Session}s.
      */
     void setSessionFactory(SessionFactory sessionFactory);
 }
@@ -27,9 +27,9 @@
 
     /**
-     * Sets the session factory to use to generate {@link org.apache.ki.session.Session Session}s.
+     * Sets the session factory to use to generate {@link org.apache.shiro.session.Session Session}s.
      *
@@ -27,9 +27,9 @@
      *
-     * @param sessionFactory the session factory to use to generate {@link org.apache.ki.session.Session Session}s.
+     * @param sessionFactory the session factory to use to generate {@link org.apache.shiro.session.Session Session}s.
      */
     void setSessionFactory(SessionFactory sessionFactory);